==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_fields/TASKID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour TASKID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TASKID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTNERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKNAME"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TASKID_Type", propOrder = {
    "partnerid",
    "taskname"
})
public class TASKID_Type {

    @XmlElement(name = "PARTNERID", required = true)
    protected String partnerid;
    @XmlElement(name = "TASKNAME", required = true)
    protected String taskname;

    /**
     * Obtient la valeur de la propriété partnerid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTNERID() {
        return partnerid;
    }

    /**
     * Définit la valeur de la propriété partnerid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTNERID(String value) {
        this.partnerid = value;
    }

    /**
     * Obtient la valeur de la propriété taskname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTASKNAME() {
        return taskname;
    }

    /**
     * Définit la valeur de la propriété taskname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTASKNAME(String value) {
        this.taskname = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/TASKID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TASKID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TASKID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTNERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKNAME"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TASKID_Type", propOrder = {
    "partnerid",
    "taskname"
})
public class TASKID_Type {

    @XmlElement(name = "PARTNERID", required = true)
    protected String partnerid;
    @XmlElement(name = "TASKNAME", required = true)
    protected String taskname;

    /**
     * Gets the value of the partnerid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTNERID() {
        return partnerid;
    }

    /**
     * Sets the value of the partnerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTNERID(String value) {
        this.partnerid = value;
    }

    /**
     * Gets the value of the taskname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTASKNAME() {
        return taskname;
    }

    /**
     * Sets the value of the taskname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTASKNAME(String value) {
        this.taskname = value;
    }

}
